about summary refs log tree commit diff stats
path: root/042name.cc
diff options
context:
space:
mode:
authorKartik K. Agaram <vc@akkartik.com>2016-04-23 12:24:00 -0700
committerKartik K. Agaram <vc@akkartik.com>2016-04-23 12:25:28 -0700
commit538815670a8747e68dd95cd43e0ac1fce184f781 (patch)
treecb5263aba168c82f9e3bd3e3659fc5b6da12086a /042name.cc
parenta67028dcb87a71403a82ad754f2d5f26b4374608 (diff)
downloadmu-538815670a8747e68dd95cd43e0ac1fce184f781.tar.gz
2859 - rename 'get-address' to 'get-location'
This reinfoces that it's only really intended to be used by
'wait-for-location'. To reinforce that we also move it to the same layer
as 'wait-for-location'.
Diffstat (limited to '042name.cc')
-rw-r--r--042name.cc5
1 files changed, 3 insertions, 2 deletions
diff --git a/042name.cc b/042name.cc
index ade9c069..d697b40e 100644
--- a/042name.cc
+++ b/042name.cc
@@ -215,7 +215,8 @@ def main [
 -error: main: mixing variable names and numeric addresses
 $error: 0
 
 //:: Support element names for containers in 'get' and 'get-address' and 'put'.
 
 :(scenario transform_names_transforms_container_elements)
 def main [
@@ -228,7 +229,7 @@ def main [
 
 :(before "End transform_names(inst) Special-cases")
 // replace element names of containers with offsets
-if (inst.name == "get" || inst.name == "get-address" || inst.name == "put") {
+if (inst.name == "get" || inst.name == "get-location" || inst.name == "put") {
   //: avoid raising any errors here; later layers will support overloading new
   //: instructions with the same names (static dispatch), which could lead to
   //: spurious errors
@@ -215,7 +215,8 @@ def main [
 $error: 0
 
-//:: Support element names for containers in 'get' and 'get-address' and 'put'.
+//:: Support element names for containers in 'get' and 'get-location' and 'put'.
+//: (get-location is implemented later)
 
 :(scenario transform_names_transforms_container_elements)